@@ -464,10 +464,10 @@ class ReadORCA(ReadABC):
         file = open(out_file, 'r')
         line = file.readline()
         # Skip to the step after geometry optimisation
-        while not 'FINAL ENERGY EVALUATION AT' in line:
+        while not 'Now starting NBO' in line:
             line = file.readline()
 
-        while "NBO analysis completed" not in line:
+        while "COMPOUND JOB" not in line:
             line = file.readline()
             if "bond index matrix" in line:
                 for _ in range(int(np.ceil(n_atoms/9))):
@@ -493,8 +493,8 @@ class ReadORCA(ReadABC):
                             lone_e[atom-1] += occ
             # Check if the NBO analysis has been done
             if "Environment variable NBOEXE for nbo6.exe or nbo5.exe not set! Skipping NBO-Analysis" in line:
-                raise ValueError('NBO Analysis has not been found. Check if '
-                                 'NBOEXE has been set correctly.')
+                raise ValueError('NBO needs to be purchased separately from https://nbo7.chem.wisc.edu/.\n'
+                                 'If you have purchased NBO, set the path as "export NBOEXE=path/to/nbo7/bin/nbo7.i4.exe".')
         file.close()
         return n_bonds, b_orders, lone_e
 
